@@ -45,7 +45,7 @@ def cupcake_factory(name):
     init.write(templates.greeter_contract)
     mkdir(f"{name}/deploy")
     init = open(f"{name}/deploy/deploy.py", "w")
-    init.write(templates.deploy_script)
+    init.write(templates.greeter_deploy)
     mkdir(f"{name}/tests")
     init = open(f"{name}/tests/tests.py", "w")
     init.write(templates.greeter_tests)
@@ -62,7 +62,7 @@ def empty_project(name):
     init.write(templates.empty_contract)
     mkdir(f"{name}/deploy")
     init = open(f"{name}/deploy/deploy.py", "w")
-    init.write(templates.deploy_script)
+    init.write(templates.empty_deploy)
     mkdir(f"{name}/tests")
     init = open(f"{name}/tests/tests.py", "w")
     init.write(templates.empty_tests)
